<?php

	/**
	 *
	 * @package   CTLT_Admin_Bar_Override
	 * @author    Richard Tape
	 * @license   GPL-2.0+
	 * @link      http://cms.ubc.ca
	 * @copyright 2014 Centre for Teaching Learning and Technology - UBC
	 *
	 * @wordpress-plugin
	 * Plugin Name:       CTLT Admin Bar Override
	 * Plugin URI:        #
	 * Description:       On a multisite install, if you're attached to many sites, the intial page load after logging in can be slow as 3 queries are made per site. This class overrides the default WordPress admin bar and prevents that.
	 * Version:           1.0.0
	 * Author:            Richard Tape
	 * Author URI:        http://cms.ubc.ca
	 * Text Domain:       ctlt-admin-bar-override
	 * License:           GPL-2.0+
	 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
	 */

	// If this file is called directly, abort.
	if( !defined( 'WPINC' ) ){
		die;
	}

	define( 'CTLT_ADMIN_BAR_OVERRIDE_PATH', plugin_dir_path( __FILE__ ) . 'ctlt-admin-bar-override/' );



	// Override the WP_Admin_Bar class
	add_filter( 'wp_admin_bar_class', 'wp_admin_bar_class__replaceAdminBarClass' );



	/**
	 * Replace the WP Admin Bar Class with our own
	 *
	 * @author Richard Tape <@richardtape>
	 * @package CTLT_Admin_Bar_Override
	 * @since 1.0
	 * @param (string) $admin_bar_class - the admin bar class to load
	 * @return (string) modified admin bar class name
	 */
	
	function wp_admin_bar_class__replaceAdminBarClass( $admin_bar_class )
	{
		
		require_once( CTLT_ADMIN_BAR_OVERRIDE_PATH . 'class-ctlt-admin-bar.php' );

		return 'CTLT_Admin_Bar';

	}/* wp_admin_bar_class__replaceAdminBarClass() */
